<?php

/**
 * @file
 * Drupal Module: DebugMe.
 *
 * File contains settings form for DebugMe module.
 */

/**
 * Implements hook_admin_settings() for module settings configuration.
 */
function debugme_admin_settings_form($form_state) {

  $form['debugme_project'] = array(
    '#title' => t('DebugMe Project ID'),
    '#type' => 'textfield',
    '#default_value' => variable_get('debugme_project', ''),
    '#size' => 15,
    '#maxlength' => 20,
    '#required' => TRUE,
    '#description' => t('This ID is unique to each project'),
  );

  // Page specific visibility configurations.
  $visibility_request_path_mode = variable_get('debugme_visibility_request_path_mode', 0);
  $visibility_request_path_pages = variable_get('debugme_visibility_request_path_pages', DEBUGME_PAGES);

  $options = array(
    t('Every page except the listed pages'),
    t('The listed pages only'),
  );

  $description = t("Specify pages by using their paths. Enter one path per line. The '*' character is a wildcard. Example paths are %blog for the blog page and %blog-wildcard for every personal blog. %front is the front page.", array(
    '%blog' => 'blog',
    '%blog-wildcard' => 'blog/*',
    '%front' => '<front>',
  ));

  $form['debugme_visibility_request_path_mode'] = array(
    '#type' => 'radios',
    '#title' => t('Add tracking to specific pages'),
    '#options' => $options,
    '#default_value' => $visibility_request_path_mode,
  );

  $form['debugme_visibility_request_path_pages'] = array(
    '#type' => 'textarea',
    '#title' => t('Pages'),
    '#title_display' => 'invisible',
    '#default_value' => $visibility_request_path_pages,
    '#description' => $description,
    '#rows' => 10,
  );

  return system_settings_form($form);
}
